@@ -93,9 +93,9 @@ int cron_open_security_session( struct passwd *pw );
 
 void cron_close_security_session( void );
 
-int cron_change_user( struct passwd *pw, char *homedir );
+int cron_change_user( struct passwd *pw );
 
-int cron_change_user_permanently( struct passwd *pw );
+int cron_change_user_permanently( struct passwd *pw, char *homedir );
 
 int get_security_context(const char *name, 
 			 int crontab_fd, 
